window.Gleam.initSearch([{"doc":"glint","title":"glint","content":"# glint\n\n[![Hex Package](https://img.shields.io/hexpm/v/glint?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glint)\n[![Hex.pm](https://img.shields.io/hexpm/dt/glint?color=ffaff3)](https://hex.pm/packages/glint)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glint/)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tanklesxl/glint/main)](https://github.com/tanklesxl/glint/actions)\n\nGleam command line argument parsing with basic flag support.\n\n## Installation\n\nTo install from hex:\n\n```sh\ngleam add glint\n```\n\n## Usage\n\n### Glint&#39;s Core\n\n`glint` is conceptually quite small, your general flow will be:\n\n1. create a new glint instance with `glint.new`\n1. configure it with `glint.with_pretty_help` and other configuration functions\n1. add commands with `glint.add`\n   1. create a new command with `glint.command`\n   1. assign that command any flags required\n   1. assign the command a custom description\n1. run your cli with `glnt.run`, run with a function to handle command output with `glint.run_and_handle`\n\n## ✨ Complementary packages\n\nGlint works amazingly with these other packages:\n\n- [argv](https://github.com/lpil/argv), use this for cross-platform argument fetching\n- [gleescript](https://github.com/lpil/gleescript), use this to generate erlang escripts for your applications\n\n## Mini Example\n\nYou can import `glint` as a dependency and use it to build simple command-line applications like the following simplified version of the [the hello world example](https://github.com/TanklesXL/glint/tree/main/examples/hello/README.md)\n\n```gleam\n// stdlib imports\nimport gleam/io\nimport gleam/list\nimport gleam/result\nimport gleam/string.{uppercase}\n// external dep imports\nimport snag\nimport argv\n// glint imports\nimport glint\nimport glint/flag\n\n\n// this function returns the builder for the caps flag\nfn caps_flag() -&gt; flag.FlagBuilder(Bool) {\n  flag.bool()\n  |&gt; flag.default(False)\n  |&gt; flag.description(&quot;Capitalize the hello message&quot;)\n}\n\n/// the glint command that will be executed\n///\nfn hello() -&gt; glint.Command(Nil) {\n  use &lt;- glint.description(&quot;Prints Hello, &lt;NAME&gt;!&quot;)\n  use caps &lt;- glint.flag(&quot;caps&quot;,caps_flag())\n  use _, args, flags &lt;- glint.command()\n  let assert Ok(caps) = caps(flags)\n  let name = case args {\n        [] -&gt; &quot;Joe&quot;\n        [name,..] -&gt; name\n  }\n  let msg = &quot;Hello, &quot; &lt;&gt; name &lt;&gt; &quot;!&quot;\n  case caps {\n    True -&gt; uppercase(msg)\n    False -&gt; msg\n  }\n  |&gt; io.println\n}\n\npub fn main() {\n  // create a new glint instance\n  glint.new()\n  // with an app name of &quot;hello&quot;, this is used when printing help text\n  |&gt; glint.with_name(&quot;hello&quot;)\n  // with pretty help enabled, using the built-in colours\n  |&gt; glint.with_pretty_help(glint.default_pretty_help())\n  // with a root command that executes the `hello` function\n  |&gt; glint.add(at: [], do: hello)\n  // execute given arguments from stdin\n  |&gt; glint.run(argv.load().arguments)\n}\n```\n","url":"index.html"},{"doc":"glint","title":"ArgsCount","content":"pub type ArgsCount {\n  EqArgs(Int)\n  MinArgs(Int)\n}\n Specify the expected number of arguments with this type and the `glint.unnamed_args` function\n\nEqArgs(Int)\n Specifies that a command must accept a specific number of arguments\n\n\nMinArgs(Int)\n Specifies that a command must accept a minimum number of arguments\n\n\nSynonyms:\nglint.ArgsCount\nglint ArgsCount","url":"glint.html#ArgsCount"},{"doc":"glint","title":"Command","content":"pub opaque type Command(a)\n A glint command\n\n\nSynonyms:\nglint.Command\nglint Command","url":"glint.html#Command"},{"doc":"glint","title":"Constraint","content":"pub type Constraint(a) =\n  fn(a) -&gt; SnagResult(a)\n Constraint type for verifying flag values\n\n\nSynonyms:\nglint.Constraint\nglint Constraint","url":"glint.html#Constraint"},{"doc":"glint","title":"Flag","content":"pub opaque type Flag(a)\n A type that facilitates the creation of `FlagEntry`s\n\n\nSynonyms:\nglint.Flag\nglint Flag","url":"glint.html#Flag"},{"doc":"glint","title":"Flags","content":"pub opaque type Flags\n FlagEntry names and their associated values\n\n\nSynonyms:\nglint.Flags\nglint Flags","url":"glint.html#Flags"},{"doc":"glint","title":"Glint","content":"pub opaque type Glint(a)\n Glint container type for config and commands\n\n\nSynonyms:\nglint.Glint\nglint Glint","url":"glint.html#Glint"},{"doc":"glint","title":"NamedArgs","content":"pub opaque type NamedArgs\n\n\nSynonyms:\nglint.NamedArgs\nglint NamedArgs","url":"glint.html#NamedArgs"},{"doc":"glint","title":"Out","content":"pub type Out(a) {\n  Out(a)\n  Help(String)\n}\n Ok type for command execution\n\nOut(a)\n Container for the command return value\n\nHelp(String)\n Container for the generated help string\n\nSynonyms:\nglint.Out\nglint Out","url":"glint.html#Out"},{"doc":"glint","title":"PrettyHelp","content":"pub type PrettyHelp {\n  PrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n}\n PrettyHelp defines the header colours to be used when styling help text\n\nPrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n\n\nSynonyms:\nglint.PrettyHelp\nglint PrettyHelp","url":"glint.html#PrettyHelp"},{"doc":"glint","title":"Result","content":"pub type Result(a) =\n  gleam.Result(Out(a), String)\n SnagResult type for command execution\n\n\nSynonyms:\nglint.Result\nglint Result","url":"glint.html#Result"},{"doc":"glint","title":"Runner","content":"pub type Runner(a) =\n  fn(NamedArgs, List(String), Flags) -&gt; a\n Functions that execute as part of glint commands.\n\n Named Arguments that a command expects will be present in the first parameter and accessible by .\n\n Flags passed to `glint` are provided as the `flags` field.\n\n\n Function type to be run by `glint`.\n\n\nSynonyms:\nglint.Runner\nglint Runner","url":"glint.html#Runner"},{"doc":"glint","title":"add","content":"pub fn add(\n  to glint: Glint(a),\n  at path: List(String),\n  do contents: Command(a),\n) -&gt; Glint(a)\n Adds a new command to be run at the specified path.\n\n If the path is `[]`, the root command is set with the provided function and\n flags.\n\n Note: all command paths are sanitized by stripping whitespace and removing any empty string elements.\n\nSynonyms:\nglint.add\nglint add","url":"glint.html#add"},{"doc":"glint","title":"as_module","content":"pub fn as_module(glint: Glint(a)) -&gt; Glint(a)\n Adjust the generated help text to reflect that the current glint app should be run as a gleam module.\n Use in conjunction with `glint.with_name` to get usage text output like `gleam run -m &lt;name&gt;`\nSynonyms:\nglint.as_module\nglint as_module","url":"glint.html#as_module"},{"doc":"glint","title":"bool","content":"pub fn bool() -&gt; Flag(Bool)\n initialise a bool flag builder\n\nSynonyms:\nglint.bool\nglint bool","url":"glint.html#bool"},{"doc":"glint","title":"command","content":"pub fn command(\n  do runner: fn(NamedArgs, List(String), Flags) -&gt; a,\n) -&gt; Command(a)\n Create a Command(a) from a Runner(a)\n\nSynonyms:\nglint.command\nglint command","url":"glint.html#command"},{"doc":"glint","title":"command_help","content":"pub fn command_help(\n  desc: String,\n  f: fn() -&gt; Command(a),\n) -&gt; Command(a)\n Attach a helptext description to a Command(a)\n\nSynonyms:\nglint.command_help\nglint command_help","url":"glint.html#command_help"},{"doc":"glint","title":"constraint","content":"pub fn constraint(\n  builder: Flag(a),\n  constraint: fn(a) -&gt; Result(a, Snag),\n) -&gt; Flag(a)\n attach a constraint to a `FlagEntry`\n\nSynonyms:\nglint.constraint\nglint constraint","url":"glint.html#constraint"},{"doc":"glint","title":"default","content":"pub fn default(for builder: Flag(a), of default: a) -&gt; Flag(a)\n Set the default value for a flag `Value`\n\nSynonyms:\nglint.default\nglint default","url":"glint.html#default"},{"doc":"glint","title":"default_pretty_help","content":"pub fn default_pretty_help() -&gt; PrettyHelp\n Default pretty help heading colouring\n mint (r: 182, g: 255, b: 234) colour for usage\n pink (r: 255, g: 175, b: 243) colour for flags\n buttercup (r: 252, g: 226, b: 174) colour for subcommands\n\nSynonyms:\nglint.default_pretty_help\nglint default_pretty_help","url":"glint.html#default_pretty_help"},{"doc":"glint","title":"each","content":"pub fn each(\n  constraint: fn(a) -&gt; Result(a, Snag),\n) -&gt; fn(List(a)) -&gt; Result(List(a), Snag)\n each is a convenience function for applying a Constraint(a) to a List(a).\n This is useful because the default behaviour for constraints on lists is that they will apply to the list as a whole.\n\n For example, to apply one_of to all items in a `List(Int)`:\n \n [1, 2, 3, 4] |&gt; one_of |&gt; each\n \nSynonyms:\nglint.each\nglint each","url":"glint.html#each"},{"doc":"glint","title":"execute","content":"pub fn execute(\n  glint: Glint(a),\n  args: List(String),\n) -&gt; Result(Out(a), String)\n Determines which command to run and executes it.\n\n Sets any provided flags if necessary.\n\n Each value prefixed with `--` is parsed as a flag.\n\n This function does not print its output and is mainly intended for use within `glint` itself.\n If you would like to print or handle the output of a command please see the `run_and_handle` function.\n\nSynonyms:\nglint.execute\nglint execute","url":"glint.html#execute"},{"doc":"glint","title":"flag","content":"pub fn flag(\n  name: String,\n  builder: Flag(a),\n  f: fn(fn(Flags) -&gt; Result(a, Snag)) -&gt; Command(b),\n) -&gt; Command(b)\n Add a `Flag` to a `Command`\n\nSynonyms:\nglint.flag\nglint flag","url":"glint.html#flag"},{"doc":"glint","title":"flag_help","content":"pub fn flag_help(\n  for builder: Flag(a),\n  of description: String,\n) -&gt; Flag(a)\n attach a helptext description to a flag\n\nSynonyms:\nglint.flag_help\nglint flag_help","url":"glint.html#flag_help"},{"doc":"glint","title":"float","content":"pub fn float() -&gt; Flag(Float)\n initialise a float flag builder\n\nSynonyms:\nglint.float\nglint float","url":"glint.html#float"},{"doc":"glint","title":"floats","content":"pub fn floats() -&gt; Flag(List(Float))\n initialise a float list flag builder\n\nSynonyms:\nglint.floats\nglint floats","url":"glint.html#floats"},{"doc":"glint","title":"get_bool","content":"pub fn get_bool(\n  from flags: Flags,\n  for name: String,\n) -&gt; Result(Bool, Snag)\n Gets the current value for the associated bool flag\n\nSynonyms:\nglint.get_bool\nglint get_bool","url":"glint.html#get_bool"},{"doc":"glint","title":"get_float","content":"pub fn get_float(\n  from flags: Flags,\n  for name: String,\n) -&gt; Result(Float, Snag)\n Gets the current value for the associated float flag\n\nSynonyms:\nglint.get_float\nglint get_float","url":"glint.html#get_float"},{"doc":"glint","title":"get_floats","content":"pub fn get_floats(\n  from flags: Flags,\n  for name: String,\n) -&gt; Result(List(Float), Snag)\n Gets the current value for the associated floats flag\n\nSynonyms:\nglint.get_floats\nglint get_floats","url":"glint.html#get_floats"},{"doc":"glint","title":"get_int","content":"pub fn get_int(\n  from flags: Flags,\n  for name: String,\n) -&gt; Result(Int, Snag)\n Gets the current value for the associated int flag\n\nSynonyms:\nglint.get_int\nglint get_int","url":"glint.html#get_int"},{"doc":"glint","title":"get_ints","content":"pub fn get_ints(\n  from flags: Flags,\n  for name: String,\n) -&gt; Result(List(Int), Snag)\n Gets the current value for the associated ints flag\n\nSynonyms:\nglint.get_ints\nglint get_ints","url":"glint.html#get_ints"},{"doc":"glint","title":"get_string","content":"pub fn get_string(\n  from flags: Flags,\n  for name: String,\n) -&gt; Result(String, Snag)\n Gets the current value for the associated string flag\n\nSynonyms:\nglint.get_string\nglint get_string","url":"glint.html#get_string"},{"doc":"glint","title":"get_strings","content":"pub fn get_strings(\n  from flags: Flags,\n  for name: String,\n) -&gt; Result(List(String), Snag)\n Gets the current value for the associated strings flag\n\nSynonyms:\nglint.get_strings\nglint get_strings","url":"glint.html#get_strings"},{"doc":"glint","title":"group_flag","content":"pub fn group_flag(\n  in glint: Glint(a),\n  at path: List(String),\n  for name: String,\n  of flag: Flag(b),\n) -&gt; Glint(a)\n Add a flag for a group of commands.\n The provided flags will be available to all commands at or beyond the provided path\n\nSynonyms:\nglint.group_flag\nglint group_flag","url":"glint.html#group_flag"},{"doc":"glint","title":"int","content":"pub fn int() -&gt; Flag(Int)\n initialise an int flag builder\n\nSynonyms:\nglint.int\nglint int","url":"glint.html#int"},{"doc":"glint","title":"ints","content":"pub fn ints() -&gt; Flag(List(Int))\n initialise an int list flag builder\n\nSynonyms:\nglint.ints\nglint ints","url":"glint.html#ints"},{"doc":"glint","title":"name","content":"pub fn name(glint: Glint(a), name: String) -&gt; Glint(a)\n Give the current glint application a name\n\nSynonyms:\nglint.name\nglint name","url":"glint.html#name"},{"doc":"glint","title":"named_arg","content":"pub fn named_arg(\n  name: String,\n  f: fn(fn(NamedArgs) -&gt; String) -&gt; Command(a),\n) -&gt; Command(a)\n Add a list of named arguments to a Command\n These named arguments will be matched with the first N arguments passed to the command\n All named arguments must match for a command to succeed\n This works in combination with CommandInput.named_args which will contain the matched args in a Dict(String,String)\n\n **IMPORTANT**: Matched named arguments will not be present in CommandInput.args\n\nSynonyms:\nglint.named_arg\nglint named_arg","url":"glint.html#named_arg"},{"doc":"glint","title":"new","content":"pub fn new() -&gt; Glint(a)\n Creates a new command tree.\n\nSynonyms:\nglint.new\nglint new","url":"glint.html#new"},{"doc":"glint","title":"none_of","content":"pub fn none_of(disallowed: List(a)) -&gt; fn(a) -&gt; Result(a, Snag)\n none_of returns a Constraint that ensures the parsed flag value is not one of the disallowed values.\n\nSynonyms:\nglint.none_of\nglint none_of","url":"glint.html#none_of"},{"doc":"glint","title":"one_of","content":"pub fn one_of(allowed: List(a)) -&gt; fn(a) -&gt; Result(a, Snag)\n one_of returns a Constraint that ensures the parsed flag value is\n one of the allowed values.\n\nSynonyms:\nglint.one_of\nglint one_of","url":"glint.html#one_of"},{"doc":"glint","title":"pretty_help","content":"pub fn pretty_help(\n  glint: Glint(a),\n  pretty: PrettyHelp,\n) -&gt; Glint(a)\n Enable custom colours for help text headers\n For a pre-made colouring use `default_pretty_help()`\n\nSynonyms:\nglint.pretty_help\nglint pretty_help","url":"glint.html#pretty_help"},{"doc":"glint","title":"run","content":"pub fn run(from glint: Glint(a), for args: List(String)) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function ignores any value returned by the command that was run.\n If you would like to do something with the command output please see the run_and_handle function.\n\nSynonyms:\nglint.run\nglint run","url":"glint.html#run"},{"doc":"glint","title":"run_and_handle","content":"pub fn run_and_handle(\n  from glint: Glint(a),\n  for args: List(String),\n  with handle: fn(a) -&gt; b,\n) -&gt; Nil\n A wrapper for `execute` that prints any errors enountered or the help text if requested.\n This function calls the provided handler with the value returned by the command that was run.\n\nSynonyms:\nglint.run_and_handle\nglint run_and_handle","url":"glint.html#run_and_handle"},{"doc":"glint","title":"string","content":"pub fn string() -&gt; Flag(String)\n initialise a string flag builder\n\nSynonyms:\nglint.string\nglint string","url":"glint.html#string"},{"doc":"glint","title":"strings","content":"pub fn strings() -&gt; Flag(List(String))\n intitialise a string list flag builder\n\nSynonyms:\nglint.strings\nglint strings","url":"glint.html#strings"},{"doc":"glint","title":"unnamed_args","content":"pub fn unnamed_args(\n  args: ArgsCount,\n  f: fn() -&gt; Command(a),\n) -&gt; Command(a)\n Specify a specific number of unnamed args that a given command expects\n\nSynonyms:\nglint.unnamed_args\nglint unnamed_args","url":"glint.html#unnamed_args"},{"doc":"glint","title":"update_flags","content":"pub fn update_flags(\n  in flags: Flags,\n  with flag_input: String,\n) -&gt; Result(Flags, Snag)\n Updates a flag value, ensuring that the new value can satisfy the required type.\n Assumes that all flag inputs passed in start with --\n This function is only intended to be used from glint.execute_root\n\nSynonyms:\nglint.update_flags\nglint update_flags","url":"glint.html#update_flags"},{"doc":"glint","title":"glint","content":"","url":"glint.html"}]);